@@ -1,6 +1,7 @@
 from .BinaryCrossentropy import BinaryCrossentropy
-from .CaloLoss import CaloLoss
+from .GlobalEventReco import GlobalEventReco
 from .JSDivergence import JSDivergence
 from .KLDivergence import KLDivergence
 from .MeanAbsoluteError import MeanAbsoluteError
 from .MeanSquaredError import MeanSquaredError
+from .PrimaryPhotonMatch import PrimaryPhotonMatch
